/*Create schema BIO_SYS_MODEL*/
DROP SCHEMA IF EXISTS BIO_SYS_MODEL;
CREATE SCHEMA BIO_SYS_MODEL;

DROP TABLE IF EXISTS BIO_SYS_MODEL.FILES;
CREATE CACHED TABLE BIO_SYS_MODEL.FILES(
    FILE_ID INT GENERATED BY DEFAULT AS IDENTITY,
    FILE_NAME VARCHAR(1024),
    GPR CHAR(3),
    CREATE_DATE TIMESTAMP,
    UPDATE_DATE TIMESTAMP,
    UNIQUE (FILE_ID)
);

CREATE INDEX FILES_FILE_NAME ON BIO_SYS_MODEL.FILES (FILE_NAME);
CREATE INDEX FILES_GPR ON BIO_SYS_MODEL.FILES (GPR);

DROP TABLE IF EXISTS BIO_SYS_MODEL.GENE_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.GENE_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    C_5_COORDINATE BIGINT, /*5'COORDINATE*/
    LOCUS_NAME VARCHAR(1024), /*Locus Tag*/
    GENE VARCHAR(1024), /*Gene*/
    PUTATIVE_ID VARCHAR(1024), /*Product*/
    PROTEIN VARCHAR(1024), /*PROTEIN*/
    REF_BLAST VARCHAR(1024), /*REF-BLAST*/
    EC_NUMBER VARCHAR(1024), /*EC Number*/
    NOTE VARCHAR(1024), /*Note*/
    OTHER VARCHAR(1024), /*Other*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX GENE_INDEX_FILE_ID ON BIO_SYS_MODEL.GENE_INDEX (FILE_ID);
CREATE INDEX GENE_INDEX_C_5_COORDINATE ON BIO_SYS_MODEL.GENE_INDEX (C_5_COORDINATE);
CREATE INDEX GENE_INDEX_LOCUS_NAME ON BIO_SYS_MODEL.GENE_INDEX (LOCUS_NAME);
CREATE INDEX GENE_INDEX_GENE ON BIO_SYS_MODEL.GENE_INDEX (GENE);
CREATE INDEX GENE_INDEX_PUTATIVE_ID ON BIO_SYS_MODEL.GENE_INDEX (PUTATIVE_ID);
CREATE INDEX GENE_INDEX_PROTEIN ON BIO_SYS_MODEL.GENE_INDEX (PROTEIN);
CREATE INDEX GENE_INDEX_REF_BLAST ON BIO_SYS_MODEL.GENE_INDEX (REF_BLAST);
CREATE INDEX GENE_INDEX_EC_NUMBER ON BIO_SYS_MODEL.GENE_INDEX (EC_NUMBER);
CREATE INDEX GENE_INDEX_NOTE ON BIO_SYS_MODEL.GENE_INDEX (NOTE);
CREATE INDEX GENE_INDEX_OTHER ON BIO_SYS_MODEL.GENE_INDEX (OTHER);

DROP TABLE IF EXISTS BIO_SYS_MODEL.PROTEIN_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.PROTEIN_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    NAME VARCHAR(1024), /*NAME*/
    GENE VARCHAR(1024), /*GENE*/
    REACTION VARCHAR(10240), /*REACTION*/
    NOTE VARCHAR(10240), /*NOTE*/
    OTHER VARCHAR(1024), /*Other*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX PROTEIN_INDEX_FILE_ID ON BIO_SYS_MODEL.PROTEIN_INDEX (FILE_ID);
CREATE INDEX PROTEIN_INDEX_ABBREVIATION ON BIO_SYS_MODEL.PROTEIN_INDEX (ABBREVIATION);
CREATE INDEX PROTEIN_INDEX_NAME ON BIO_SYS_MODEL.PROTEIN_INDEX (NAME);
CREATE INDEX PROTEIN_INDEX_GENE ON BIO_SYS_MODEL.PROTEIN_INDEX (GENE);
CREATE INDEX PROTEIN_INDEX_REACTION ON BIO_SYS_MODEL.PROTEIN_INDEX (REACTION);
CREATE INDEX PROTEIN_INDEX_NOTE ON BIO_SYS_MODEL.PROTEIN_INDEX (NOTE);
CREATE INDEX PROTEIN_INDEX_OTHER ON BIO_SYS_MODEL.PROTEIN_INDEX (OTHER);

DROP TABLE IF EXISTS BIO_SYS_MODEL.REACTION_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.REACTION_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    NAME VARCHAR(1024), /*NAME*/
    EQUATION VARCHAR(4096), /*EQUATION*/
    PROTEIN VARCHAR(4096), /*PROTEIN*/
    SUBSYSTEM VARCHAR(1024), /*SUBSYSTEM*/
    CONFIDENCE VARCHAR(1024),
    NOTE VARCHAR(10240), /*REACTION*/
    OTHER VARCHAR(1024), /*Other*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX REACTION_INDEX_FILE_ID ON BIO_SYS_MODEL.REACTION_INDEX (FILE_ID);
CREATE INDEX REACTION_INDEX_ABBREVIATION ON BIO_SYS_MODEL.REACTION_INDEX (ABBREVIATION);
CREATE INDEX REACTION_INDEX_NAME ON BIO_SYS_MODEL.REACTION_INDEX (NAME);
CREATE INDEX REACTION_INDEX_EQUATION ON BIO_SYS_MODEL.REACTION_INDEX (EQUATION);
CREATE INDEX REACTION_INDEX_PROTEIN ON BIO_SYS_MODEL.REACTION_INDEX (PROTEIN);
CREATE INDEX REACTION_INDEX_SUBSYSTEM ON BIO_SYS_MODEL.REACTION_INDEX (SUBSYSTEM);
CREATE INDEX REACTION_INDEX_CONFIDENCE ON BIO_SYS_MODEL.REACTION_INDEX (CONFIDENCE);
CREATE INDEX REACTION_INDEX_NOTE ON BIO_SYS_MODEL.REACTION_INDEX (NOTE);
CREATE INDEX REACTION_INDEX_OTHER ON BIO_SYS_MODEL.REACTION_INDEX (OTHER);

DROP TABLE IF EXISTS BIO_SYS_MODEL.INVALID_REACTION_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.INVALID_REACTION_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    NAME VARCHAR(1024), /*NAME*/
    EQUATION VARCHAR(4096), /*EQUATION*/
    ASSOCIATION LONGVARCHAR, /*PROTEIN OR GENE*/
    SUBSYSTEM VARCHAR(1024), /*SUBSYSTEM*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX INVALID_REACTION_INDEX_FILE_ID ON BIO_SYS_MODEL.INVALID_REACTION_INDEX (FILE_ID);
CREATE INDEX INVALID_REACTION_INDEX_ABBREVIATION ON BIO_SYS_MODEL.INVALID_REACTION_INDEX (ABBREVIATION);
CREATE INDEX INVALID_REACTION_INDEX_NAME ON BIO_SYS_MODEL.INVALID_REACTION_INDEX (NAME);
CREATE INDEX INVALID_REACTION_INDEX_EQUATION ON BIO_SYS_MODEL.INVALID_REACTION_INDEX (EQUATION);
CREATE INDEX INVALID_REACTION_INDEX_ASSOCIATION ON BIO_SYS_MODEL.INVALID_REACTION_INDEX (ASSOCIATION);
CREATE INDEX INVALID_REACTION_INDEX_SUBSYSTEM ON BIO_SYS_MODEL.INVALID_REACTION_INDEX (SUBSYSTEM);

DROP TABLE IF EXISTS BIO_SYS_MODEL.INNERCELL_REACTION_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.INNERCELL_REACTION_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    NAME VARCHAR(1024), /*NAME*/
    EQUATION VARCHAR(4096), /*EQUATION*/
    ASSOCIATION LONGVARCHAR, /*Association*/
    SUBSYSTEM VARCHAR(1024), /*SUBSYSTEM*/
    OBJECTIVE_COEFFICIENT INT, /*OBJECTIVE_COEFFICIENT*/
    LB VARCHAR(1024), /*LB*/
    UB VARCHAR(1024), /*UB*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX INNERCELL_REACTION_INDEX_FILE_ID ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (FILE_ID);
CREATE INDEX INNERCELL_REACTION_INDEX_ABBREVIATION ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (ABBREVIATION);
CREATE INDEX INNERCELL_REACTION_INDEX_NAME ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (NAME);
CREATE INDEX INNERCELL_REACTION_INDEX_EQUATION ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (EQUATION);
CREATE INDEX INNERCELL_REACTION_INDEX_ASSOCIATION ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (ASSOCIATION);
CREATE INDEX INNERCELL_REACTION_INDEX_SUBSYSTEM ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (SUBSYSTEM);
CREATE INDEX INNERCELL_REACTION_INDEX_OBJECTIVE_COEFFICIENT ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (OBJECTIVE_COEFFICIENT);
CREATE INDEX INNERCELL_REACTION_INDEX_LB ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (LB);
CREATE INDEX INNERCELL_REACTION_INDEX_UB ON BIO_SYS_MODEL.INNERCELL_REACTION_INDEX (UB);

DROP TABLE IF EXISTS BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    EQUATION VARCHAR(1024), /*EQUATION*/
    OBJECTIVE_COEFFICIENT INT, /*OBJECTIVE_COEFFICIENT*/
    LB VARCHAR(1024), /*LB*/
    UB VARCHAR(1024), /*UB*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX EXCHANGECELL_REACTION_INDEX_FILE_ID ON BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX (FILE_ID);
CREATE INDEX EXCHANGECELL_REACTION_INDEX_ABBREVIATION ON BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX (ABBREVIATION);
CREATE INDEX EXCHANGECELL_REACTION_INDEX_EQUATION ON BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX (EQUATION);
CREATE INDEX EXCHANGECELL_REACTION_INDEX_OBJECTIVE_COEFFICIENT ON BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX (OBJECTIVE_COEFFICIENT);
CREATE INDEX EXCHANGECELL_REACTION_INDEX_LB ON BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX (LB);
CREATE INDEX EXCHANGECELL_REACTION_INDEX_UB ON BIO_SYS_MODEL.EXCHANGECELL_REACTION_INDEX (UB);

DROP TABLE IF EXISTS BIO_SYS_MODEL.METABOLITES_INDEX;
CREATE CACHED TABLE BIO_SYS_MODEL.METABOLITES_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    COMPARTMENT VARCHAR(1024), /*COMPARTMENT*/
    NAME VARCHAR(1024), /*NAME*/
    FORMULA VARCHAR(1024), /*FORMULA*/
    CHARGE VARCHAR(1000),
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX METABOLITES_INDEX_FILE_ID ON BIO_SYS_MODEL.METABOLITES_INDEX (FILE_ID);
CREATE INDEX METABOLITES_INDEX_ABBREVIATION ON BIO_SYS_MODEL.METABOLITES_INDEX (ABBREVIATION);
CREATE INDEX METABOLITES_INDEX_COMPARTMENT ON BIO_SYS_MODEL.METABOLITES_INDEX (COMPARTMENT);
CREATE INDEX METABOLITES_INDEX_NAME ON BIO_SYS_MODEL.METABOLITES_INDEX (NAME);
CREATE INDEX METABOLITES_INDEX_FORMULA ON BIO_SYS_MODEL.METABOLITES_INDEX (FORMULA);
CREATE INDEX METABOLITES_INDEX_CHARGE ON BIO_SYS_MODEL.METABOLITES_INDEX (CHARGE);

/*Create schema BIO_REF_DB*/
DROP SCHEMA IF EXISTS BIO_REF_DB;
CREATE SCHEMA BIO_REF_DB;

DROP TABLE IF EXISTS BIO_REF_DB.METABOLITE;
CREATE CACHED TABLE BIO_REF_DB.METABOLITE(
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1000),
    NAME VARCHAR(1000),
    FORMULA VARCHAR(1000),
    CHARGE VARCHAR(1000),
    CASNUMBER VARCHAR(1000),
    COMPOUND_NAMES VARCHAR(1000),
    KEGGID VARCHAR(1000),
    NOTE LONGVARCHAR,
    UNIQUE (ROW_NUM)
);

CREATE INDEX METABOLITE_ABBREVIATION ON BIO_REF_DB.METABOLITE (ABBREVIATION);
CREATE INDEX METABOLITE_NAME ON BIO_REF_DB.METABOLITE (NAME);
CREATE INDEX METABOLITE_FORMULA ON BIO_REF_DB.METABOLITE (FORMULA);
CREATE INDEX METABOLITE_CHARGE ON BIO_REF_DB.METABOLITE (CHARGE);
CREATE INDEX METABOLITE_CASNUMBER ON BIO_REF_DB.METABOLITE (CASNUMBER);
CREATE INDEX METABOLITE_COMPOUND_NAMES ON BIO_REF_DB.METABOLITE (COMPOUND_NAMES);
CREATE INDEX METABOLITE_KEGGID ON BIO_REF_DB.METABOLITE (KEGGID);
CREATE INDEX METABOLITE_NOTE ON BIO_REF_DB.METABOLITE (NOTE);

DROP TABLE IF EXISTS BIO_REF_DB.PROTEIN_INDEX;
CREATE CACHED TABLE BIO_REF_DB.PROTEIN_INDEX(
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1000),
    NAME VARCHAR(1000),
    NOTE LONGVARCHAR,
    UNIQUE (ROW_NUM)
);

CREATE INDEX PROTEIN_INDEX_ABBREVIATION ON BIO_REF_DB.PROTEIN_INDEX (ABBREVIATION);
CREATE INDEX PROTEIN_INDEX_NAME ON BIO_REF_DB.PROTEIN_INDEX (NAME);
CREATE INDEX PROTEIN_INDEX_NOTE ON BIO_REF_DB.PROTEIN_INDEX (NOTE);

DROP TABLE IF EXISTS BIO_REF_DB.REACTION_INDEX;
CREATE CACHED TABLE BIO_REF_DB.REACTION_INDEX(
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1000),
    NAME VARCHAR(1000),
    EQUATION VARCHAR(4096),
    NOTE LONGVARCHAR,
    KEGGID VARCHAR(1000),
    VALIDATION VARCHAR(1024),
    UNIQUE (ROW_NUM)
);

CREATE INDEX REACTION_INDEX_ABBREVIATION ON BIO_REF_DB.REACTION_INDEX (ABBREVIATION);
CREATE INDEX REACTION_INDEX_NAME ON BIO_REF_DB.REACTION_INDEX (NAME);
CREATE INDEX REACTION_INDEX_EQUATION ON BIO_REF_DB.REACTION_INDEX (EQUATION);
CREATE INDEX REACTION_INDEX_NOTE ON BIO_REF_DB.REACTION_INDEX (NOTE);
CREATE INDEX REACTION_INDEX_KEGGID ON BIO_REF_DB.REACTION_INDEX (KEGGID);
CREATE INDEX REACTION_INDEX_VALIDATION ON BIO_REF_DB.REACTION_INDEX (VALIDATION);

/*Create schema BIO_GR_SYS_MODEL*/
DROP SCHEMA IF EXISTS BIO_GR_SYS_MODEL;
CREATE SCHEMA BIO_GR_SYS_MODEL;

DROP TABLE IF EXISTS BIO_GR_SYS_MODEL.GENE_INDEX;
CREATE CACHED TABLE BIO_GR_SYS_MODEL.GENE_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    C_5_COORDINATE BIGINT, /*5'COORDINATE*/
    LOCUS_NAME VARCHAR(1024), /*Locus Tag*/
    GENE VARCHAR(1024), /*GENE*/
    PUTATIVE_ID VARCHAR(1024), /*Product*/
    REACTION VARCHAR(4096), /*REACTION*/
    REF_BLAST VARCHAR(1024), /*REF-BLAST*/
    EC_NUMBER VARCHAR(1024), /*EC NUMBER*/
    NOTE VARCHAR(1024), /*NOTE*/
    OTHER VARCHAR(1024), /*Other*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX GENE_INDEX_FILE_ID ON BIO_GR_SYS_MODEL.GENE_INDEX (FILE_ID);
CREATE INDEX GENE_INDEX_C_5_COORDINATE ON BIO_GR_SYS_MODEL.GENE_INDEX (C_5_COORDINATE);
CREATE INDEX GENE_INDEX_LOCUS_NAME ON BIO_GR_SYS_MODEL.GENE_INDEX (LOCUS_NAME);
CREATE INDEX GENE_INDEX_GENE ON BIO_GR_SYS_MODEL.GENE_INDEX (GENE);
CREATE INDEX GENE_INDEX_PUTATIVE_ID ON BIO_GR_SYS_MODEL.GENE_INDEX (PUTATIVE_ID);
CREATE INDEX GENE_INDEX_REACTION ON BIO_GR_SYS_MODEL.GENE_INDEX (REACTION);
CREATE INDEX GENE_INDEX_REF_BLAST ON BIO_GR_SYS_MODEL.GENE_INDEX (REF_BLAST);
CREATE INDEX GENE_INDEX_EC_NUMBER ON BIO_GR_SYS_MODEL.GENE_INDEX (EC_NUMBER);
CREATE INDEX GENE_INDEX_NOTE ON BIO_GR_SYS_MODEL.GENE_INDEX (NOTE);
CREATE INDEX GENE_INDEX_OTHER ON BIO_GR_SYS_MODEL.GENE_INDEX (OTHER);

DROP TABLE IF EXISTS BIO_GR_SYS_MODEL.REACTION_INDEX;
CREATE CACHED TABLE BIO_GR_SYS_MODEL.REACTION_INDEX(
    FILE_ID INT,
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1024), /*ABBREVIATION*/
    NAME VARCHAR(1024), /*NAME*/
    EQUATION VARCHAR(4096), /*EQUATION*/
    GENE LONGVARCHAR, /*GENE*/
    SUBSYSTEM VARCHAR(1024), /*SUBSYSTEM*/
    CONFIDENCE VARCHAR(1024),
    NOTE VARCHAR(10240), /*REACTION*/
    OTHER VARCHAR(1024), /*Other*/
    UNIQUE (FILE_ID, ROW_NUM)
);

CREATE INDEX REACTION_INDEX_FILE_ID ON BIO_GR_SYS_MODEL.REACTION_INDEX (FILE_ID);
CREATE INDEX REACTION_INDEX_ABBREVIATION ON BIO_GR_SYS_MODEL.REACTION_INDEX (ABBREVIATION);
CREATE INDEX REACTION_INDEX_NAME ON BIO_GR_SYS_MODEL.REACTION_INDEX (NAME);
CREATE INDEX REACTION_INDEX_EQUATION ON BIO_GR_SYS_MODEL.REACTION_INDEX (EQUATION);
CREATE INDEX REACTION_INDEX_GENE ON BIO_GR_SYS_MODEL.REACTION_INDEX (GENE);
CREATE INDEX REACTION_INDEX_SUBSYSTEM ON BIO_GR_SYS_MODEL.REACTION_INDEX (SUBSYSTEM);
CREATE INDEX REACTION_INDEX_CONFIDENCE ON BIO_GR_SYS_MODEL.REACTION_INDEX (CONFIDENCE);
CREATE INDEX REACTION_INDEX_NOTE ON BIO_GR_SYS_MODEL.REACTION_INDEX (NOTE);
CREATE INDEX REACTION_INDEX_OTHER ON BIO_GR_SYS_MODEL.REACTION_INDEX (OTHER);

/*Create schema BIO_GR_REF_DB*/
DROP SCHEMA IF EXISTS BIO_GR_REF_DB;
CREATE SCHEMA BIO_GR_REF_DB;

DROP TABLE IF EXISTS BIO_GR_REF_DB.METABOLITE;
CREATE CACHED TABLE BIO_GR_REF_DB.METABOLITE(
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1000),
    NAME VARCHAR(1000),
    FORMULA VARCHAR(1000),
    CHARGE VARCHAR(1000),
    CASNUMBER VARCHAR(1000),
    COMPOUND_NAMES VARCHAR(1000),
    KEGGID VARCHAR(1000),
    NOTE LONGVARCHAR,
    UNIQUE (ROW_NUM)
);

CREATE INDEX METABOLITE_ABBREVIATION ON BIO_GR_REF_DB.METABOLITE (ABBREVIATION);
CREATE INDEX METABOLITE_NAME ON BIO_GR_REF_DB.METABOLITE (NAME);
CREATE INDEX METABOLITE_FORMULA ON BIO_GR_REF_DB.METABOLITE (FORMULA);
CREATE INDEX METABOLITE_CHARGE ON BIO_GR_REF_DB.METABOLITE (CHARGE);
CREATE INDEX METABOLITE_CASNUMBER ON BIO_GR_REF_DB.METABOLITE (CASNUMBER);
CREATE INDEX METABOLITE_COMPOUND_NAMES ON BIO_GR_REF_DB.METABOLITE (COMPOUND_NAMES);
CREATE INDEX METABOLITE_KEGGID ON BIO_GR_REF_DB.METABOLITE (KEGGID);
CREATE INDEX METABOLITE_NOTE ON BIO_GR_REF_DB.METABOLITE (NOTE);

DROP TABLE IF EXISTS BIO_GR_REF_DB.REACTION_INDEX;
CREATE CACHED TABLE BIO_GR_REF_DB.REACTION_INDEX(
    ROW_NUM INT,
    ABBREVIATION VARCHAR(1000),
    NAME VARCHAR(1000),
    EQUATION VARCHAR(4096),
    NOTE LONGVARCHAR,
    KEGGID VARCHAR(1000),
    VALIDATION VARCHAR(1024),
    UNIQUE (ROW_NUM)
);

CREATE INDEX REACTION_INDEX_ABBREVIATION ON BIO_GR_REF_DB.REACTION_INDEX (ABBREVIATION);
CREATE INDEX REACTION_INDEX_NAME ON BIO_GR_REF_DB.REACTION_INDEX (NAME);
CREATE INDEX REACTION_INDEX_EQUATION ON BIO_GR_REF_DB.REACTION_INDEX (EQUATION);
CREATE INDEX REACTION_INDEX_NOTE ON BIO_GR_REF_DB.REACTION_INDEX (NOTE);
CREATE INDEX REACTION_INDEX_KEGGID ON BIO_GR_REF_DB.REACTION_INDEX (KEGGID);
CREATE INDEX REACTION_INDEX_VALIDATION ON BIO_GR_REF_DB.REACTION_INDEX (VALIDATION);
